==> haskell-th-abstraction-0.4.2.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.4.2.0
visibility:           public
id:                   th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
key:                  th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  29af257d6d1c454c46937f091491c86d
exposed:              True
exposed-modules:
    Language.Haskell.TH.Datatype Language.Haskell.TH.Datatype.TyVarBndr

hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/th-abstraction-0.4.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/th-abstraction-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/th-abstraction-0.4.2.0
hs-libraries:         HSth-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1
    template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.4.2.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.4.2.0
visibility:           public
id:                   th-abstraction-0.4.2.0-DYHW6JC9drp3AaDf8Ov8bI
key:                  th-abstraction-0.4.2.0-DYHW6JC9drp3AaDf8Ov8bI
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  0a69ecf71d40340c3cbfbdfabdb72cf4
exposed:              True
exposed-modules:
    Language.Haskell.TH.Datatype Language.Haskell.TH.Datatype.TyVarBndr

hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-abstraction-0.4.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-abstraction-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-abstraction-0.4.2.0
hs-libraries:         HSth-abstraction-0.4.2.0-DYHW6JC9drp3AaDf8Ov8bI
depends:
    base-4.15.0.0 containers-0.6.4.1 ghc-prim-0.7.0
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
